changeset 263:b3c0268f7815

updated for version 7.0071
author vimboss
date Sun, 24 Apr 2005 22:04:21 +0000
parents 9286b314563f
children f8484ba33f48
files runtime/doc/tags src/charset.c src/misc2.c src/version.h
diffstat 4 files changed, 18 insertions(+), 19 deletions(-) [+]
line wrap: on
line diff
--- a/runtime/doc/tags
+++ b/runtime/doc/tags
@@ -5117,6 +5117,7 @@ hebrew	hebrew.txt	/*hebrew*
 hebrew.txt	hebrew.txt	/*hebrew.txt*
 help	various.txt	/*help*
 help-context	help.txt	/*help-context*
+help-tags	tags	1
 help-translated	various.txt	/*help-translated*
 help-xterm-window	various.txt	/*help-xterm-window*
 help.txt	help.txt	/*help.txt*
--- a/src/charset.c
+++ b/src/charset.c
@@ -991,14 +991,15 @@ init_spell_chartab()
     else
 #endif
     {
-	/* Rough guess: use isalpha() for characters above 128. */
+	/* Rough guess: use isalpha() and isupper() for characters above 128.
+	 * */
 	for (i = 128; i < 256; ++i)
 	{
-	    spelltab.st_isw[i] = isalpha(i);
-	    if (isupper(i))
+	    spelltab.st_isw[i] = MB_ISUPPER(i) || MB_ISLOWER(i);
+	    if (MB_ISUPPER(i))
 	    {
 		spelltab.st_isu[i] = TRUE;
-		spelltab.st_fold[i] = tolower(i);
+		spelltab.st_fold[i] = MB_TOLOWER(i);
 	    }
 	}
     }
@@ -1150,6 +1151,8 @@ set_spell_finish(new_st)
 #if defined(FEAT_MBYTE) || defined(PROTO)
 /*
  * Write the current tables into the .spl file.
+ * This makes sure the same characters are recognized as word characters when
+ * generating an when using a spell file.
  */
     void
 write_spell_chartab(fd)
@@ -1160,15 +1163,6 @@ write_spell_chartab(fd)
     int		flags;
     int		i;
 
-    if (!did_set_spelltab)
-    {
-	/* No character table specified, write zero counts. */
-	fputc(0, fd);
-	fputc(0, fd);
-	fputc(0, fd);
-	return;
-    }
-
     fputc(128, fd);				    /* <charflagslen> */
     for (i = 128; i < 256; ++i)
     {
--- a/src/version.h
+++ b/src/version.h
@@ -36,5 +36,5 @@
 #define VIM_VERSION_NODOT	"vim70aa"
 #define VIM_VERSION_SHORT	"7.0aa"
 #define VIM_VERSION_MEDIUM	"7.0aa ALPHA"
-#define VIM_VERSION_LONG	"VIM - Vi IMproved 7.0aa ALPHA (2005 Apr 23)"
-#define VIM_VERSION_LONG_DATE	"VIM - Vi IMproved 7.0aa ALPHA (2005 Apr 23, compiled "
+#define VIM_VERSION_LONG	"VIM - Vi IMproved 7.0aa ALPHA (2005 Apr 24)"
+#define VIM_VERSION_LONG_DATE	"VIM - Vi IMproved 7.0aa ALPHA (2005 Apr 24, compiled "
--- a/src/misc2.c
+++ b/src/misc2.c
@@ -2474,11 +2474,15 @@ get_pseudo_mouse_code(button, is_click, 
 	    && is_drag == mouse_table[i].is_drag)
 	{
 #ifdef FEAT_GUI
-	    /* Trick: a non mappable left click and release has mouse_col < 0.
-	     * Used for 'mousefocus' in gui_mouse_moved() */
-	    if (mouse_col < 0)
+	    /* Trick: a non mappable left click and release has mouse_col -1
+	     * or added MOUSE_COLOFF.  Used for 'mousefocus' in
+	     * gui_mouse_moved() */
+	    if (mouse_col < 0 || mouse_col > MOUSE_COLOFF)
 	    {
-		mouse_col = 0;
+		if (mouse_col < 0)
+		    mouse_col = 0;
+		else
+		    mouse_col -= MOUSE_COLOFF;
 		if (mouse_table[i].pseudo_code == (int)KE_LEFTMOUSE)
 		    return (int)KE_LEFTMOUSE_NM;
 		if (mouse_table[i].pseudo_code == (int)KE_LEFTRELEASE)